Mapof — Map of Objects

Skip to main content
`Ctrl`+`K`

# Mapof

This open-source, MIT-licensed package is a core part of the mapof ecosystem. This framework allow for representing various features of (computational) problem instances in the context of the instance structure in a visually appealing way. Mapof is a direct successor of mapel, which will be deprecated in the (unforeseen) future.

## Mapof Components

List of available packages within the mapof ecosystem:

- Mapof-elections

- Mapof-roommates

- Mapof-marriages

- Mapof-tournaments (coming soon)

- Mapof-allocations (coming soon)